pub enum PreviousBootDataProviderRequest {
WatchPreviousBootData {
options: PreviousBootDataProviderOptions,
responder: PreviousBootDataProviderWatchPreviousBootDataResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: PreviousBootDataProviderControlHandle,
method_type: MethodType,
},
}Variants
WatchPreviousBootData
Hanging get: Returns the data once it has been rotated and is ready.
If the data is already ready when this method is called, the responder returns immediately. Otherwise, the responder holds the request until the data becomes available.
Clients should only call this method once per boot. This data does not change across a given boot.
Fields

options: PreviousBootDataProviderOptions#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: PreviousBootDataProviderControlHandle
method_type: MethodTypeImplementations
Sourceimpl PreviousBootDataProviderRequest
impl PreviousBootDataProviderRequest
pub fn into_watch_previous_boot_data( self, ) -> Option<(PreviousBootDataProviderOptions, PreviousBootDataProviderWatchPreviousBootDataResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL