pub struct PreviousBootDataProviderMarker;Trait Implementations
Sourceimpl Clone for PreviousBootDataProviderMarker
impl Clone for PreviousBootDataProviderMarker
Sourcefn clone(&self) -> PreviousBootDataProviderMarker
fn clone(&self) -> PreviousBootDataProviderMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PreviousBootDataProviderMarker
Sourceimpl DiscoverableProtocolMarker for PreviousBootDataProviderMarker
impl DiscoverableProtocolMarker for PreviousBootDataProviderMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for PreviousBootDataProviderMarker
Sourceimpl Ord for PreviousBootDataProviderMarker
impl Ord for PreviousBootDataProviderMarker
Sourcefn cmp(&self, other: &PreviousBootDataProviderMarker) -> Ordering
fn cmp(&self, other: &PreviousBootDataProviderMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for PreviousBootDataProviderMarker
impl PartialOrd for PreviousBootDataProviderMarker
Sourceimpl ProtocolMarker for PreviousBootDataProviderMarker
impl ProtocolMarker for PreviousBootDataProviderMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.diagnostics.persistence.PreviousBootDataProvider"
const DEBUG_NAME: &'static str = "fuchsia.diagnostics.persistence.PreviousBootDataProvider"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PreviousBootDataProviderProxy
type Proxy = PreviousBootDataProviderProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PreviousBootDataProviderRequestStream
type RequestStream = PreviousBootDataProviderRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = PreviousBootDataProviderSynchronousProxy
type SynchronousProxy = PreviousBootDataProviderSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for PreviousBootDataProviderMarker