pub struct PreviousBootDataProviderProxy { /* private fields */ }Implementations
Sourceimpl PreviousBootDataProviderProxy
impl PreviousBootDataProviderProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.diagnostics.persistence/PreviousBootDataProvider.
Sourcepub fn take_event_stream(&self) -> PreviousBootDataProviderEventStream
pub fn take_event_stream(&self) -> PreviousBootDataProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch_previous_boot_data(
&self,
options: &PreviousBootDataProviderOptions,
) -> QueryResponseFut<PreviousBootData, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch_previous_boot_data( &self, options: &PreviousBootDataProviderOptions, ) -> QueryResponseFut<PreviousBootData, DefaultFuchsiaResourceDialect> ⓘ
Hanging get: Returns the data once it has been rotated and is ready.
If the data is already ready when this method is called, the responder returns immediately. Otherwise, the responder holds the request until the data becomes available.
Clients should only call this method once per boot. This data does not change across a given boot.