pub struct PreviousBootDataProviderSynchronousProxy { /* private fields */ }Implementations
Sourceimpl PreviousBootDataProviderSynchronousProxy
impl PreviousBootDataProviderSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<PreviousBootDataProviderEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<PreviousBootDataProviderEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn watch_previous_boot_data(
&self,
options: &PreviousBootDataProviderOptions,
___deadline: MonotonicInstant,
) -> Result<PreviousBootData, Error>
pub fn watch_previous_boot_data( &self, options: &PreviousBootDataProviderOptions, ___deadline: MonotonicInstant, ) -> Result<PreviousBootData, Error>
Hanging get: Returns the data once it has been rotated and is ready.
If the data is already ready when this method is called, the responder returns immediately. Otherwise, the responder holds the request until the data becomes available.
Clients should only call this method once per boot. This data does not change across a given boot.