pub struct PreviousBootDataProviderWatchPreviousBootDataResponder { /* private fields */ }Implementations
Sourceimpl PreviousBootDataProviderWatchPreviousBootDataResponder
impl PreviousBootDataProviderWatchPreviousBootDataResponder
Sourcepub fn send(self, data: PreviousBootData) -> Result<(), Error>
pub fn send(self, data: PreviousBootData) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
data: PreviousBootData,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, data: PreviousBootData, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.