pub struct PreviousBootDataProviderWatchPreviousBootDataResponse {
pub data: PreviousBootData,
}Fields
data: PreviousBootDataTrait Implementations
Sourceimpl Decode<PreviousBootDataProviderWatchPreviousBootDataResponse, DefaultFuchsiaResourceDialect> for PreviousBootDataProviderWatchPreviousBootDataResponse
impl Decode<PreviousBootDataProviderWatchPreviousBootDataResponse, DefaultFuchsiaResourceDialect> for PreviousBootDataProviderWatchPreviousBootDataResponse
Sourceimpl Encode<PreviousBootDataProviderWatchPreviousBootDataResponse, DefaultFuchsiaResourceDialect> for &mut PreviousBootDataProviderWatchPreviousBootDataResponse
impl Encode<PreviousBootDataProviderWatchPreviousBootDataResponse, DefaultFuchsiaResourceDialect> for &mut PreviousBootDataProviderWatchPreviousBootDataResponse
Sourceimpl<T0: Encode<PreviousBootData, DefaultFuchsiaResourceDialect>> Encode<PreviousBootDataProviderWatchPreviousBootDataResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<PreviousBootData, DefaultFuchsiaResourceDialect>> Encode<PreviousBootDataProviderWatchPreviousBootDataResponse, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl ResourceTypeMarker for PreviousBootDataProviderWatchPreviousBootDataResponse
impl ResourceTypeMarker for PreviousBootDataProviderWatchPreviousBootDataResponse
Sourcetype Borrowed<'a> = &'a mut PreviousBootDataProviderWatchPreviousBootDataResponse
type Borrowed<'a> = &'a mut PreviousBootDataProviderWatchPreviousBootDataResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for PreviousBootDataProviderWatchPreviousBootDataResponse
impl StructuralPartialEq for PreviousBootDataProviderWatchPreviousBootDataResponse
Sourceimpl TypeMarker for PreviousBootDataProviderWatchPreviousBootDataResponse
impl TypeMarker for PreviousBootDataProviderWatchPreviousBootDataResponse
Sourcetype Owned = PreviousBootDataProviderWatchPreviousBootDataResponse
type Owned = PreviousBootDataProviderWatchPreviousBootDataResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for PreviousBootDataProviderWatchPreviousBootDataResponse
impl RefUnwindSafe for PreviousBootDataProviderWatchPreviousBootDataResponse
impl Send for PreviousBootDataProviderWatchPreviousBootDataResponse
impl Sync for PreviousBootDataProviderWatchPreviousBootDataResponse
impl Unpin for PreviousBootDataProviderWatchPreviousBootDataResponse
impl UnsafeUnpin for PreviousBootDataProviderWatchPreviousBootDataResponse
impl UnwindSafe for PreviousBootDataProviderWatchPreviousBootDataResponse