pub struct PreviousBootData {
pub monotonic_timestamp: Option<MonotonicInstant>,
pub boot_timestamp: Option<BootInstant>,
pub utc_timestamp_ns: Option<i64>,
pub inspect: Option<ClientEnd<FileMarker>>,
/* private fields */
}Expand description
Represents the processed data from the previous boot once it is ready.
Fields
monotonic_timestamp: Option<MonotonicInstant>The monotonic timestamp associated with when this data was captured/processed.
boot_timestamp: Option<BootInstant>The boot timestamp associated with when this data was captured/processed.
utc_timestamp_ns: Option<i64>The UTC timestamp at which this data was captured, if the UTC time was at logging quality. This field is omitted if UTC is not available or not at logging quality. See //sdk/fidl/fuchsia.time.fidl for reference.
inspect: Option<ClientEnd<FileMarker>>An open, read-only file handle to the processed data file. The client can read the data directly from this channel.